@@ -80,10 +80,10 @@ public:
  * @param result resultado acumulado
  * @param elem nuevo vector solución a sumar
  */
-tChromosomeReal &accumulate_var(tChromosomeReal &result, tChromosomeReal &elem) {
-   int i, ndim=result.size();
+tChromosomeReal accumulate_var(tChromosomeReal result, const tChromosomeReal &elem) {
+   int ndim = result.size();
 
-   for (i = 0; i < ndim; ++i) {
+   for (int i = 0; i < ndim; ++i) {
       result[i] += elem[i];
    }
 
@@ -92,6 +92,7 @@ tChromosomeReal &accumulate_var(tChromosomeReal &result, tChromosomeReal &elem)
 
 
 
+
 void SimplexParams::calculateCentroide(void) {
    int ndim = m_simplex[0].size();
 
